import request from "@/utils/request";

// 查询辅助指标-综保区列表
export function listQUOTABONDED(query) {
  return request({
    url: "/business/QUOTABONDED/list",
    method: "get",
    params: query,
  });
}

// 查询辅助指标-综保区所有列表
export function listAllQUOTABONDED(query) {
  return request({
    url: "/business/QUOTABONDED/listAll",
    method: "get",
    params: query,
  });
}

// 查询辅助指标-综保区详细
export function getQUOTABONDED(id) {
  return request({
    url: "/business/QUOTABONDED/getInfo/" + id,
    method: "get",
  });
}

// 新增辅助指标-综保区
export function addQUOTABONDED(data) {
  return request({
    url: "/business/QUOTABONDED/add",
    method: "post",
    data: data,
  });
}

// 修改辅助指标-综保区
export function updateQUOTABONDED(data) {
  return request({
    url: "/business/QUOTABONDED/edit",
    method: "post",
    data: data,
  });
}

// 删除辅助指标-综保区
export function delQUOTABONDED(id) {
  return request({
    url: "/business/QUOTABONDED/remove/" + id,
    method: "get",
  });
}

// 用户提交审核，辅助指标
export function setApprove(data) {
  return request({
    url: "/business/QUOTABONDED/audit",
    method: "post",
    params: data,
  });
}


// 管理员审核，辅助指标
export function setAdminApprove(data) {
  return request({
    url: "/business/QUOTABONDED/approval",
    method: "post",
    params: data,
  });
}

// 管理员上报，辅助指标
export function setAdminReport(data) {
  return request({
    url: "/business/QUOTABONDED/report",
    method: "post",
    params: data,
  });
}